@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.80 2012/06/16 12:52:04 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.87 2013/02/05 10:32:31 jasper Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -300,7 +300,15 @@ my $stem_extensions = {
 	'libmpcdec' => 'musepack',
 	'mppenc' => 'musepack',
 	'xxxterm' => 'xombrero',
-	'pecl-zip' => 'php-zip'
+	'pecl-zip' => 'php-zip',
+	'XML-Sablotron' => 'p5-XML-Sablotron',
+# 5.3
+	'postler' => 'geary',
+	'tangogps' => 'foxtrotgps',
+	'cyrus-imapd-perl' => 'cyrus-imapd',
+	'tmw' => 'manaplus',
+        'ruby19-ruby-augeas' => 'ruby19-augeas',
+        'ruby-ruby-augeas' => 'ruby-augeas'
 };
 
 # ->is_base_system($handle, $state):
